@@ -148,8 +148,8 @@ class APTPlugin(Plugin):
                     logging.debug(f"Package {name} is part of the base system.")
                     continue
                 default.append(name)
-        sudo().cc(["apt-get", "install", "-y"] + default)
-        sudo().cc(["apt-mark", "auto"] + default)
+        if default:
+            sudo().cc(["apt-get", "install", "-y"] + default)
         for package in manual:
             p = Path(package["path"]).expanduser()
             check_call([p / "build.sh"], pwd=p)
@@ -168,9 +168,10 @@ class SnapPlugin(Plugin):
         try:
             out = set()
             for line in check_output(["snap", "list"]).decode("utf-8").splitlines()[1:]:
-                if line in ("core",):
+                name = line.split()[0]
+                if name in ("core",):
                     continue
-                out.add(line)
+                out.add(name)
             return out
         except:
             logging.warning("Failed to get snap packages", exc_info=True)
@@ -238,8 +239,11 @@ def main():
     plugins = [plugin() for plugin in PLUGINS]
 
     command = args._command
-    if not command:
+    if command:
+        args_conf = args.conf
+    else:
         command = "sync"
+        args_conf = "decapt.luxem"
 
     if command == "generate":
         conf = dict(installed=[])
@@ -249,14 +253,14 @@ def main():
                     conf["installed"].append(package)
                 else:
                     conf["installed"].append(luxem.Typed(plugin.id(), package))
-        if not args.force and os.path.exists(args.conf):
-            print(f"{args.conf} already exists. Delete it or run with `-f`.")
+        if not args.force and os.path.exists(args_conf):
+            print(f"{args_conf} already exists. Delete it or run with `-f`.")
             return
-        with open(args.conf, "w") as out:
+        with open(args_conf, "w") as out:
             luxem.dump(out, conf, pretty=True)
 
     elif command == "sync":
-        with open(args.conf, "r") as conff:
+        with open(args_conf, "r") as conff:
             conf = luxem.load(conff)[0]
         want = dict()
         add = dict()
